@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Licenses {
-    client: Client,
+    pub client: Client,
 }
 
 impl Licenses {
@@ -33,24 +33,18 @@ impl Licenses {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::LicenseSimple>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if featured {
-            query_args.push(format!("featured={}", featured));
+            query_args.push(("featured".to_string(), featured.to_string()));
         }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/licenses?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/licenses?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -70,18 +64,12 @@ impl Licenses {
         &self,
         featured: bool,
     ) -> Result<Vec<crate::types::LicenseSimple>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if featured {
-            query_args.push(format!("featured={}", featured));
+            query_args.push(("featured".to_string(), featured.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/licenses?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/licenses?{}", query_);
 
         self.client.get_all_pages(&url, None).await
     }
@@ -99,7 +87,7 @@ impl Licenses {
      *
      * * `license: &str`
      */
-    pub async fn get(&self, license: &str) -> Result<crate::types::License> {
+    pub async fn get(&self, license: &str) -> Result<crate::types::LicenseData> {
         let url = format!(
             "/licenses/{}",
             crate::progenitor_support::encode_path(&license.to_string()),
