@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Search {
-    client: Client,
+    pub client: Client,
 }
 
 impl Search {
@@ -54,26 +54,24 @@ impl Search {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::SearchCodeResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("order={}", order));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !order.to_string().is_empty() {
+            query_args.push(("order".to_string(), order.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if !q.is_empty() {
-            query_args.push(format!("q={}", q));
+            query_args.push(("q".to_string(), q.to_string()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
-        let url = format!("/search/code?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/search/code?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -110,26 +108,24 @@ impl Search {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::SearchCommitsResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("order={}", order));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !order.to_string().is_empty() {
+            query_args.push(("order".to_string(), order.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if !q.is_empty() {
-            query_args.push(format!("q={}", q));
+            query_args.push(("q".to_string(), q.to_string()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
-        let url = format!("/search/commits?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/search/commits?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -170,26 +166,24 @@ impl Search {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::SearchIssuesPullRequestsResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("order={}", order));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !order.to_string().is_empty() {
+            query_args.push(("order".to_string(), order.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if !q.is_empty() {
-            query_args.push(format!("q={}", q));
+            query_args.push(("q".to_string(), q.to_string()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
-        let url = format!("/search/issues?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/search/issues?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -229,29 +223,27 @@ impl Search {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::SearchLabelsResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("order={}", order));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !order.to_string().is_empty() {
+            query_args.push(("order".to_string(), order.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if !q.is_empty() {
-            query_args.push(format!("q={}", q));
+            query_args.push(("q".to_string(), q.to_string()));
         }
         if repository_id > 0 {
-            query_args.push(format!("repository_id={}", repository_id));
+            query_args.push(("repository_id".to_string(), repository_id.to_string()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
-        let url = format!("/search/labels?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/search/labels?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -293,26 +285,24 @@ impl Search {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::SearchReposResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("order={}", order));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !order.to_string().is_empty() {
+            query_args.push(("order".to_string(), order.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if !q.is_empty() {
-            query_args.push(format!("q={}", q));
+            query_args.push(("q".to_string(), q.to_string()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
-        let url = format!("/search/repositories?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/search/repositories?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -346,24 +336,18 @@ impl Search {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::SearchTopicsResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if !q.is_empty() {
-            query_args.push(format!("q={}", q));
+            query_args.push(("q".to_string(), q.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/search/topics?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/search/topics?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -401,26 +385,24 @@ impl Search {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::SearchUsersResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("order={}", order));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !order.to_string().is_empty() {
+            query_args.push(("order".to_string(), order.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if !q.is_empty() {
-            query_args.push(format!("q={}", q));
+            query_args.push(("q".to_string(), q.to_string()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
-        let url = format!("/search/users?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/search/users?{}", query_);
 
         self.client.get(&url, None).await
     }
